16.66. cdist-type__install_generate_fstab(7) — cdist 6.5.4 documentation

# 16.66. cdist-type__install_generate_fstab(7)

## 16.66.1. NAME

cdist-type__install_generate_fstab - generate /etc/fstab during installation

## 16.66.2. DESCRIPTION

Generates a /etc/fstab file from information retrieved from __install_mount definitions.

## 16.66.3. REQUIRED PARAMETERS

destination
  The path where to store the generated fstab file. Note that this is a path on the server, where cdist is running, not the target host.

## 16.66.4. OPTIONAL PARAMETERS

None

## 16.66.5. BOOLEAN PARAMETERS

uuid
  use UUID instead of device in fstab

## 16.66.6. EXAMPLES

    __install_generate_fstab --destination /path/where/you/want/fstab

    __install_generate_fstab --uuid --destination /path/where/you/want/fstab

## 16.66.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.66.8. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.